@@ -171,7 +171,7 @@ except ModuleNotFoundError:
 try:
     import numba # type: ignore
     if has_numpy:
-        _haversine_kernel_vector = numba.vectorize(fastmath=True)(_haversine_kernel)
+        _haversine_kernel_vector = numba.vectorize(fastmath=True)(_haversine_kernel_vector)
         # Tuple output is not supported for numba.vectorize. Just jit the numpy version.
         _inverse_haversine_kernel_vector = numba.njit(fastmath=True)(_inverse_haversine_kernel_vector)
     _haversine_kernel = numba.njit(_haversine_kernel)
@@ -273,13 +273,18 @@ def haversine_vector(array1, array2, unit=Unit.KILOMETERS, comb=False, normalize
     return get_avg_earth_radius(unit) * _haversine_kernel_vector(lat1, lng1, lat2, lng2)
 
 
-def inverse_haversine(point, distance, direction: Union[Direction, float], unit=Unit.KILOMETERS):
+def inverse_haversine(point, distance, direction: Union[Direction, float], unit=Unit.KILOMETERS, normalize_output=False):
     lat, lng = point
     r = get_avg_earth_radius(unit)
-    return _inverse_haversine_kernel(lat, lng, direction, distance/r)
+    outLat, outLng = _inverse_haversine_kernel(lat, lng, direction, distance / r)
+
+    if normalize_output:
+        return _normalize(outLat, outLng)
+    else:
+        return (outLat, outLng)
 
 
-def inverse_haversine_vector(array, distance, direction, unit=Unit.KILOMETERS):
+def inverse_haversine_vector(array, distance, direction, unit=Unit.KILOMETERS, normalize_output=False): # -> Tuple["numpy.ndarray", "numpy.ndarray"]:
     if not has_numpy:
         raise RuntimeError('Error, unable to import Numpy, '
                            'consider using inverse_haversine instead of inverse_haversine_vector.')
@@ -299,4 +304,9 @@ def inverse_haversine_vector(array, distance, direction, unit=Unit.KILOMETERS):
     lat, lng = array[:, 0], array[:, 1]
 
     r = get_avg_earth_radius(unit)
-    return _inverse_haversine_kernel_vector(lat, lng, direction, distance/r)
+    outLatArray, outLngArray = _inverse_haversine_kernel_vector(lat, lng, direction, distance/r)
+
+    if normalize_output:
+        return _normalize_vector(outLatArray, outLngArray)
+
+    return (outLatArray, outLngArray)
\ No newline at end of file
